==> apache-superset-2.0.1-source.tar.gz: apache-superset-2.0.1rc6/superset-frontend/plugins/plugin-chart-echarts/src/BigNumber/CHANGELOG.md <==
<!--
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->

# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# [0.18.0](https://github.com/apache-superset/superset-ui/compare/v0.17.87...v0.18.0) (2021-08-30)

**Note:** Version bump only for package @superset-ui/legacy-preset-chart-big-number





## [0.17.62](https://github.com/apache-superset/superset-ui/compare/v0.17.61...v0.17.62) (2021-07-02)

**Note:** Version bump only for package @superset-ui/legacy-preset-chart-big-number





## [0.17.61](https://github.com/apache-superset/superset-ui/compare/v0.17.60...v0.17.61) (2021-07-02)


### Bug Fixes

* **legacy-preset-chart-big-number:** example images got mixed up ([#1196](https://github.com/apache-superset/superset-ui/issues/1196)) ([60215b5](https://github.com/apache-superset/superset-ui/commit/60215b5a4c5ae416fc27418c276276ed38ab7f19))

==> apache-superset-4.0.0-source.tar.gz: apache-superset-4.0.0rc2/superset-frontend/plugins/plugin-chart-echarts/src/BigNumber/CHANGELOG.md <==
<!--
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->

# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# [0.18.0](https://github.com/apache-superset/superset-ui/compare/v0.17.87...v0.18.0) (2021-08-30)

**Note:** Version bump only for package @superset-ui/legacy-preset-chart-big-number

## [0.17.62](https://github.com/apache-superset/superset-ui/compare/v0.17.61...v0.17.62) (2021-07-02)

**Note:** Version bump only for package @superset-ui/legacy-preset-chart-big-number

## [0.17.61](https://github.com/apache-superset/superset-ui/compare/v0.17.60...v0.17.61) (2021-07-02)

### Bug Fixes

- **legacy-preset-chart-big-number:** example images got mixed up ([#1196](https://github.com/apache-superset/superset-ui/issues/1196)) ([60215b5](https://github.com/apache-superset/superset-ui/commit/60215b5a4c5ae416fc27418c276276ed38ab7f19))
